Skip to main content

dataserv-client

BuildLink CoverageLink LicenseLink IssuesLink

Contributing

We welcome contributions if you have a little extra time and Python experience. We ask that you make your pull requests on the develop branch, as we only use master for releases. Please follow PEP8, and make sure you document anything new. If you have any questions, you can find the entire team on Slack. Note: If you plan on running the unit tests for the repo, you will also need to have dataserv running locally with a new db.

Setup

Windows

Download latest windows release from github.

Extract the zip file to the folder where you wish to have it installed.

$ dataserv-client.exe version

The dataserv-client will automatically update when new releases are made.

Linux (Ubuntu/Mint/Debian)

Install client

# install apt dependencies
$ sudo apt-get install python python-pip graphviz
$ sudo apt-get install python-dev libgraphviz-dev pkg-config gcc

# Some systems may need to install graphviz from the system package first.
$ sudo pip install pygraphviz --install-option="--include-path=/usr/include/graphviz" --install-option="--library-path=/usr/lib/graphviz/"

$ sudo pip install dataserv-client
$ dataserv-client version

Update client

$ sudo pip install dataserv-client --upgrade
$ dataserv-client version

OSX

Install client

$ brew install python
$ rehash
$ pip install dataserv-client
$ dataserv-client version

Update client

$ pip install dataserv-client --upgrade
$ dataserv-client version

Farmer Quickstart Guide

Configure your farmer node

Optionally set a cold storage payout address. You can set a counterparty wallet address here. All configuration must be done before starting the node.

dataserv-client config --set_payout_address=<BITCOIN_ADDRESS>

Start your farmer node

Optionally specify the path to store data, the available space, and minimum free space.

dataserv-client --store_path=<PATH> --max_size=<SIZE_IN_BYTES> --min_free_size=<SIZE_IN_BYTES> farm

Optional max_size and min_free_size syntax

--max_size=1.0K  # 1024^1 bytes
--max_size=1.0KB # 1000^1 bytes
--max_size=1.0M  # 1024^2 bytes
--max_size=1.0MB # 1000^2 bytes
--max_size=1.0G  # 1024^3 bytes
--max_size=1.0GB # 1000^3 bytes
--max_size=1.0T  # 1024^4 bytes
--max_size=1.0TB # 1000^4 bytes
--max_size=1.0P  # 1024^5 bytes
--max_size=1.0PB # 1000^5 bytes

Farmer Multi Disc Guide

In order to farm on multiple discs you will have to run several instances, as multiple paths are not yet supported. To do this you will need one config for each disc.

Different instances can share a common payout address, however it is recommended to use a different payout address for each instance.

Disc 1

dataserv-client --config_path=<CONFIG 1> config --set_payout_address=<BITCOIN_ADDRESS 1>
dataserv-client --config_path=<CONFIG 1> --store_path=<PATH 1> --max_size=<SIZE 1> farm

Disc n

dataserv-client --config_path=<CONFIG n> config --set_payout_address=<BITCOIN_ADDRESS n>
dataserv-client --config_path=<CONFIG n> --store_path=<PATH n> --max_size=<SIZE n> farm

Farmer Setting Custom Height

In order to build a bit faster, you may consider using the –set_height_interval command. If you set a high height number though please also consider running another instance of the client with poll. Poll will send every 60 sec, farm or build will send only when the height interval is reached.

Running the farm command

dataserv-client --url=http://switch.driveshare.org --store_path=<PATH> --max_size=<SIZE_IN_BYTES> farm --set_height_interval=(default: 25, max recommended: 199999)

Running the poll command

dataserv-client --url=http://switch.driveshare.org poll

Workers Guide

You can start multiple workers by executing farm or build with the optional argument –workers. It is recommended to start only as many workers as your cpu and hard drive can handle. With a fast hard drive a cpu usage of ~80% is possible.

dataserv-client build --workers=<number of workers>
dataserv-client farm --workers=<number of workers>

Command Line Interface Usage

Argument ordering

$ dataserv-client <program arguments> COMMAND <command arguments>

Argument ordering example

$ dataserv-client --debug build --rebuild

Show program help, optional arguments and commands

$ dataserv-client --help
usage: dataserv-client [-h] [--url URL] [--max_size MAX_SIZE]
                       [--store_path STORE_PATH] [--config_path CONFIG_PATH]
                       [--debug] [--use_folder_tree]
                       <command> ...

Dataserve client command-line interface.

optional arguments:
  -h, --help            show this help message and exit
  --url URL             Url of the farmer (default:
                        http://status.driveshare.org).
  --max_size MAX_SIZE   Maximum data size in bytes. (default: 1073741824).
  --min_free_size MIN_FREE_SIZE
                        Minimum free size in bytes. (default: 1073741824).
  --store_path STORE_PATH
                        Storage path. (default: /home/user/.storj/store).
  --config_path CONFIG_PATH
                        Config path. (default: /home/user/.storj/config.json).
  --debug               Show debug information.
  --use_folder_tree     Use folder tree to store files (always on for fat32
                        store_path).

commands:
  <command>
    version             Show version number.
    register            Register your node on the network.
    ping                Ping master node.
    poll                Let the network know your are online.
    build               Fill the farmer with data up to their max.
    audit               Audit the generated data.
    config              Edit and display config.
    farm                Start farmer.

Show command help and optional arguments

$ dataserv-client config --help
usage: dataserv-client config [-h] [--set_wallet SET_WALLET]
                              [--set_payout_address SET_PAYOUT_ADDRESS]

optional arguments:
  -h, --help            show this help message and exit
  --set_wallet SET_WALLET
                        Set node wallet to given hwif.
  --set_payout_address SET_PAYOUT_ADDRESS
                        Root address of wallet used by default.

Metadata

Release files for dataserv-client 2.1.12

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Built distribution (wheel)

Table of built distributions (wheels) for dataserv-client 2.1.12
File Interpreter ABI Platform
dataserv_client-2.1.12-py2-none-any.whl Python 2 none any Details

Release files / dataserv_client-2.1.12-py2-none-any.whl

Download URL dataserv_client-2.1.12-py2-none-any.whl
Size 27.6 kB
Tags Python 2
SHA-256 checksum
How to use checksums
74cf0d349efe124de2a3e29803f1bcea8bd515edcd9b6ea487117555b58ffb42
BLAKE2b-256 checksum
How to use checksums
1ea49d61e9f2c26aab5fef847431d8f5f19889ec23e5e7b09410adfcddc81b45
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Security for dataserv-client 2.1.12

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

No provenance found

None of the files in this release were uploaded with provenance metadata.

A note on package security

PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.

To learn more about protecting yourself from malicious actors, visit our package security documentation.

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page